@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Module that provides functionality for user manipulation."""
 
 from AccessControl.Permission import getPermissions
@@ -24,7 +23,7 @@ def create(
     email=None,
     username=None,
     password=None,
-    roles=('Member', ),
+    roles=("Member",),
     properties=None,
 ):
     """Create a user.
@@ -45,7 +44,7 @@ def create(
     :raises:
         MissingParameterError
         InvalidParameterError
-    :Example: :ref:`user_create_example`
+    :Example: :ref:`user-create-example`
     """
     if properties is None:
         # Never use a dict as default for a keyword argument.
@@ -53,34 +52,26 @@ def create(
 
     # it may happen that someone passes email in the properties dict, catch
     # that and set the email so the code below this works fine
-    if not email and properties.get('email'):
-        email = properties.get('email')
+    if not email and properties.get("email"):
+        email = properties.get("email")
 
     if not email:
         raise MissingParameterError("You need to pass the new user's email.")
 
-    try:
-        use_email_as_username = portal.get_registry_record(
-            'plone.use_email_as_login',
-        )
-    except InvalidParameterError:
-        site = portal.get()
-        props = site.portal_properties
-        use_email_as_username = props.site_properties.use_email_as_login
-
+    use_email_as_username = portal.get_registry_record("plone.use_email_as_login")
     if not use_email_as_username and not username:
         raise InvalidParameterError(
-            'The portal is configured to use username '
-            'that is not email so you need to pass a username.',
+            "The portal is configured to use username "
+            "that is not email so you need to pass a username.",
         )
 
-    registration = portal.get_tool('portal_registration')
+    registration = portal.get_tool("portal_registration")
     user_id = use_email_as_username and email or username
 
     # Generate a random 8-char password
     if not password:
         chars = string.ascii_letters + string.digits
-        password = ''.join(random.choice(chars) for char in range(8))
+        password = "".join(random.choice(chars) for char in range(8))
 
     properties.update(username=user_id)
     properties.update(email=email)
@@ -94,8 +85,8 @@ def create(
     return get(username=user_id)
 
 
-@mutually_exclusive_parameters('userid', 'username')
-@at_least_one_of('userid', 'username')
+@mutually_exclusive_parameters("userid", "username")
+@at_least_one_of("userid", "username")
 def get(userid=None, username=None):
     """Get a user.
 
@@ -117,10 +108,10 @@ def get(userid=None, username=None):
     :rtype: MemberData object
     :raises:
         MissingParameterError
-    :Example: :ref:`user_get_example`
+    :Example: :ref:`user-get-example`
     """
     if userid is not None:
-        portal_membership = portal.get_tool('portal_membership')
+        portal_membership = portal.get_tool("portal_membership")
         return portal_membership.getMemberById(userid)
 
     return get_member_by_login_name(
@@ -135,13 +126,13 @@ def get_current():
 
     :returns: Currently logged-in user
     :rtype: MemberData object
-    :Example: :ref:`user_get_current_example`
+    :Example: :ref:`user-get-current-example`
     """
-    portal_membership = portal.get_tool('portal_membership')
+    portal_membership = portal.get_tool("portal_membership")
     return portal_membership.getAuthenticatedMember()
 
 
-@mutually_exclusive_parameters('groupname', 'group')
+@mutually_exclusive_parameters("groupname", "group")
 def get_users(groupname=None, group=None):
     """Get all users or all users filtered by group.
 
@@ -154,18 +145,18 @@ def get_users(groupname=None, group=None):
     :param group: Group of which to return users.
         If set, only return users that are member of this group.
     :type group: GroupData object
-    :returns: All users (optionlly filtered by group)
+    :returns: All users (optionally filtered by group)
     :rtype: List of MemberData objects
-    :Example: :ref:`user_get_all_users_example`,
-        :ref:`user_get_groups_users_example`
+    :Example: :ref:`user-get-all-users-example`,
+        :ref:`user-get-groups-users-example`
     """
     if groupname:
-        group_tool = portal.get_tool('portal_groups')
+        group_tool = portal.get_tool("portal_groups")
         group = group_tool.getGroupById(groupname)
         if not group:
             raise GroupNotFoundError
 
-    portal_membership = portal.get_tool('portal_membership')
+    portal_membership = portal.get_tool("portal_membership")
 
     if group:
         return group.getGroupMembers()
@@ -173,8 +164,8 @@ def get_users(groupname=None, group=None):
         return portal_membership.listMembers()
 
 
-@mutually_exclusive_parameters('username', 'user')
-@at_least_one_of('username', 'user')
+@mutually_exclusive_parameters("username", "user")
+@at_least_one_of("username", "user")
 def delete(username=None, user=None):
     """Delete a user.
 
@@ -188,9 +179,9 @@ def delete(username=None, user=None):
     :raises:
         MissingParameterError
         InvalidParameterError
-    :Example: :ref:`user_delete_example`
+    :Example: :ref:`user-delete-example`
     """
-    portal_membership = portal.get_tool('portal_membership')
+    portal_membership = portal.get_tool("portal_membership")
     user_id = username or user.id
     portal_membership.deleteMembers((user_id,))
 
@@ -200,12 +191,12 @@ def is_anonymous():
 
     :returns: True if the current user is anonymous, False otherwise.
     :rtype: bool
-    :Example: :ref:`user_is_anonymous_example`
+    :Example: :ref:`user-is-anonymous-example`
     """
-    return bool(portal.get_tool('portal_membership').isAnonymousUser())
+    return bool(portal.get_tool("portal_membership").isAnonymousUser())
 
 
-@mutually_exclusive_parameters('username', 'user')
+@mutually_exclusive_parameters("username", "user")
 def get_roles(username=None, user=None, obj=None, inherit=True):
     """Get user's site-wide or local roles.
 
@@ -225,9 +216,9 @@ def get_roles(username=None, user=None, obj=None, inherit=True):
     :type inherit: bool
     :raises:
         MissingParameterError
-    :Example: :ref:`user_get_roles_example`
+    :Example: :ref:`user-get-roles-example`
     """
-    portal_membership = portal.get_tool('portal_membership')
+    portal_membership = portal.get_tool("portal_membership")
 
     if username is None:
         if user is None:
@@ -253,7 +244,7 @@ def get_roles(username=None, user=None, obj=None, inherit=True):
             principal_ids = list(plone_user.getGroups())
             principal_ids.insert(0, plone_user.getId())
             roles = set()
-            pas = portal.get_tool('acl_users')
+            pas = portal.get_tool("acl_users")
             for _, lrmanager in pas.plugins.listPlugins(ILocalRolesPlugin):
                 for adapter in lrmanager._getAdapters(obj):
                     for principal_id in principal_ids:
@@ -265,11 +256,11 @@ def get_roles(username=None, user=None, obj=None, inherit=True):
 
 @contextmanager
 def _nop_context_manager():
-    """A trivial context manager that does nothing."""
+    """Do nothing (trivial context manager)."""
     yield
 
 
-@mutually_exclusive_parameters('username', 'user')
+@mutually_exclusive_parameters("username", "user")
 def get_permissions(username=None, user=None, obj=None):
     """Get user's site-wide or local permissions.
 
@@ -287,7 +278,7 @@ def get_permissions(username=None, user=None, obj=None):
     :type obj: content object
     :raises:
         InvalidParameterError
-    :Example: :ref:`user_get_permissions_example`
+    :Example: :ref:`user-get-permissions-example`
     """
     if obj is None:
         obj = portal.get()
@@ -304,9 +295,9 @@ def get_permissions(username=None, user=None, obj=None):
     return result
 
 
-@mutually_exclusive_parameters('username', 'user')
+@mutually_exclusive_parameters("username", "user")
 def has_permission(permission, username=None, user=None, obj=None):
-    """Check whether this user has the given permssion.
+    """Check whether this user has the given permission.
 
     Arguments ``username`` and ``user`` are mutually exclusive. You
     can either set one or the other, but not both. if ``username`` and
@@ -339,8 +330,8 @@ def has_permission(permission, username=None, user=None, obj=None):
         return bool(getSecurityManager().checkPermission(permission, obj))
 
 
-@required_parameters('roles')
-@mutually_exclusive_parameters('username', 'user')
+@required_parameters("roles")
+@mutually_exclusive_parameters("username", "user")
 def grant_roles(username=None, user=None, obj=None, roles=None):
     """Grant roles to a user.
 
@@ -360,19 +351,19 @@ def grant_roles(username=None, user=None, obj=None, roles=None):
     :raises:
         InvalidParameterError
         MissingParameterError
-    :Example: :ref:`user_grant_roles_example`
+    :Example: :ref:`user-grant-roles-example`
     """
     if user is None:
         user = get(username=username)
     # check we got a user
     if user is None:
-        raise InvalidParameterError('User could not be found')
+        raise InvalidParameterError("User could not be found")
 
     if isinstance(roles, tuple):
         roles = list(roles)
 
     # These roles cannot be granted
-    if 'Anonymous' in roles or 'Authenticated' in roles:
+    if "Anonymous" in roles or "Authenticated" in roles:
         raise InvalidParameterError
 
     if obj is None:
@@ -388,8 +379,8 @@ def grant_roles(username=None, user=None, obj=None, roles=None):
         obj.manage_setLocalRoles(user.getId(), roles)
 
 
-@required_parameters('roles')
-@mutually_exclusive_parameters('username', 'user')
+@required_parameters("roles")
+@mutually_exclusive_parameters("username", "user")
 def revoke_roles(username=None, user=None, obj=None, roles=None):
     """Revoke roles from a user.
 
@@ -408,17 +399,17 @@ def revoke_roles(username=None, user=None, obj=None, roles=None):
     :type roles: list of strings
     :raises:
         InvalidParameterError
-    :Example: :ref:`user_revoke_roles_example`
+    :Example: :ref:`user-revoke-roles-example`
     """
     if user is None:
         user = get(username=username)
     # check we got a user
     if user is None:
-        raise InvalidParameterError('User could not be found')
+        raise InvalidParameterError("User could not be found")
 
     roles = set(roles)
 
-    if 'Anonymous' in roles or 'Authenticated' in roles:
+    if "Anonymous" in roles or "Authenticated" in roles:
         raise InvalidParameterError
 
     inherit = True
@@ -426,11 +417,11 @@ def revoke_roles(username=None, user=None, obj=None, roles=None):
         # if obj, get only a list of local roles, without inherited ones
         inherit = False
 
-    actual_roles = set([
+    actual_roles = {
         role
         for role in get_roles(user=user, obj=obj, inherit=inherit)
-        if role not in ['Anonymous', 'Authenticated']
-    ])
+        if role not in ["Anonymous", "Authenticated"]
+    }
 
     roles = list(actual_roles - roles)
 
